DeterministicCborNegativeInteger

Struct DeterministicCborNegativeInteger 

pub struct DeterministicCborNegativeInteger { /* private fields */ }
Validated negative integer in the deterministic-CBOR supported range.

The field is private so callers cannot bypass DeterministicCborInteger::negative and create a nonnegative value in the negative-integer variant.

Implementations

Source

impl DeterministicCborNegativeInteger

pub const fn value(&self) -> i64

Return the validated negative value.