pub fn supported_table() -> Result<MulticodecTable<'static>, MulticodecOperationError>Expand description
Return all supported multicodec entries in stable registry order.
pub fn supported_table() -> Result<MulticodecTable<'static>, MulticodecOperationError>Return all supported multicodec entries in stable registry order.