MulticodecSpec

Struct MulticodecSpec 

pub struct MulticodecSpec<'a> { /* private fields */ }
Borrowed semantic metadata for one supported multicodec entry.

Implementations

Source

impl<'a> MulticodecSpec<'a>

pub const fn name(&self) -> &'a str

Return the canonical registry name.

pub const fn tag(&self) -> CodecTag

Return the semantic registry class.

pub const fn key_material(&self) -> KeyMaterialKind

Return the key-material classification.

pub const fn algorithm_name(&self) -> &'a str

Return the public algorithm name.

pub const fn code(&self) -> &'a [u8] ⓘ

Return the encoded multicodec varint bytes.

pub const fn prefix(&self) -> &'a [u8] ⓘ

Return the prefix bytes matched or prepended by codec operations.

pub const fn length(&self) -> MulticodecLength

Return the semantic length rule for values described by this entry.